@@ -220,7 +220,7 @@ gnome_db_base_new ()
 	GObject   *obj;
 
 	GnomeDbBase *base;
-	obj = g_object_new (GNOME_DB_BASE_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_BASE, NULL);
 	base = GNOME_DB_BASE (obj);
 
 	return obj;
