@@ -29,8 +29,8 @@
 G_BEGIN_DECLS
 
 #define GNOME_DB_TYPE_DATA_HANDLER          (gnome_db_data_handler_get_type())
-#define GNOME_DB_DATA_HANDLER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_data_handler_get_type(), GnomeDbDataHandler)
-#define IS_GNOME_DB_DATA_HANDLER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_data_handler_get_type ())
+#define GNOME_DB_DATA_HANDLER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_DATA_HANDLER, GnomeDbDataHandler)
+#define IS_GNOME_DB_DATA_HANDLER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_DATA_HANDLER)
 #define GNOME_DB_DATA_HANDLER_GET_IFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GNOME_DB_TYPE_DATA_HANDLER, GnomeDbDataHandlerIface))
 
 
