@@ -21,7 +21,7 @@
 #ifndef __GNOME_DB_DECL_H_
 #define __GNOME_DB_DECL_H_
 
-#include "gnome-db-i18n.h"
+#include <glib/gi18n-lib.h>
 
 /* Define how the SQL functions and aggregates are
  * tested for their arguments.
@@ -135,6 +135,10 @@ typedef struct _GnomeDbQfFunc GnomeDbQfFunc;
 typedef struct _GnomeDbQfFuncClass GnomeDbQfFuncClass;
 typedef struct _GnomeDbQfFuncPrivate GnomeDbQfFuncPrivate;
 
+typedef struct _GnomeDbQfAgg GnomeDbQfAgg;
+typedef struct _GnomeDbQfAggClass GnomeDbQfAggClass;
+typedef struct _GnomeDbQfAggPrivate GnomeDbQfAggPrivate;
+
 /*
  * Data model handling
  */
