@@ -65,10 +65,7 @@ static GSList           *gnome_db_model_wrapper_model_get_key_columns  (GnomeDbD
 static void                 gnome_db_model_wrapper_data_model_init (GdaDataModelIface *iface);
 static gint                 gnome_db_model_wrapper_get_n_rows      (GdaDataModel *model);
 static gint                 gnome_db_model_wrapper_get_n_columns   (GdaDataModel *model);
-static GdaColumn  *gnome_db_model_wrapper_describe_column (GdaDataModel *model, gint col);
-static const gchar         *gnome_db_model_wrapper_get_column_title(GdaDataModel *model, gint col);
-static void                 gnome_db_model_wrapper_set_column_title(GdaDataModel *model, gint col, const gchar *title);
-static gint                 gnome_db_model_wrapper_get_column_pos  (GdaDataModel *model, const gchar *title);
+static GdaColumn           *gnome_db_model_wrapper_describe_column (GdaDataModel *model, gint col);
 static const GdaRow        *gnome_db_model_wrapper_get_row         (GdaDataModel *model, gint row);
 static const GdaValue      *gnome_db_model_wrapper_get_value_at    (GdaDataModel *model, gint col, gint row);
 static gboolean             gnome_db_model_wrapper_is_updatable    (GdaDataModel *model);
@@ -79,9 +76,7 @@ static gboolean             gnome_db_model_wrapper_cancel_changes  (GdaDataModel
 static const GdaRow        *gnome_db_model_wrapper_append_row      (GdaDataModel *model, const GList *values);
 static gboolean             gnome_db_model_wrapper_remove_row      (GdaDataModel *model, const GdaRow *row);
 static gboolean             gnome_db_model_wrapper_update_row      (GdaDataModel *model, const GdaRow *row);
-static gboolean             gnome_db_model_wrapper_append_column   (GdaDataModel *model, const GdaColumn *attrs);
-static gboolean             gnome_db_model_wrapper_update_column   (GdaDataModel *model, gint col,
-                                                                 const GdaColumn *attrs);
+static GdaColumn           *gnome_db_model_wrapper_append_column   (GdaDataModel *model);
 static gboolean             gnome_db_model_wrapper_remove_column   (GdaDataModel *model, gint col);
 static void                 gnome_db_model_wrapper_set_notify      (GdaDataModel *model, gboolean do_notify_changes);
 static gboolean             gnome_db_model_wrapper_get_notify      (GdaDataModel *model);
@@ -166,10 +161,10 @@ gnome_db_model_wrapper_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbModelWrapper", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbModelWrapper", &info, 0);
 		g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &gda_model_info);
-		g_type_add_interface_static (type, GNOME_DB_ENTITY_TYPE, &entity_info);
-		g_type_add_interface_static (type, GNOME_DB_DATA_MODEL_TYPE, &model_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_ENTITY, &entity_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_MODEL, &model_info);
 	}
 	return type;
 }
@@ -194,9 +189,6 @@ gnome_db_model_wrapper_data_model_init (GdaDataModelIface *iface)
         iface->i_get_n_rows = gnome_db_model_wrapper_get_n_rows;
         iface->i_get_n_columns = gnome_db_model_wrapper_get_n_columns;
         iface->i_describe_column = gnome_db_model_wrapper_describe_column;
-        iface->i_get_column_title = gnome_db_model_wrapper_get_column_title;
-        iface->i_set_column_title = gnome_db_model_wrapper_set_column_title;
-        iface->i_get_column_pos = gnome_db_model_wrapper_get_column_pos;
         iface->i_get_row = gnome_db_model_wrapper_get_row;
         iface->i_get_value_at = gnome_db_model_wrapper_get_value_at;
         iface->i_is_updatable = gnome_db_model_wrapper_is_updatable;
@@ -207,8 +199,6 @@ gnome_db_model_wrapper_data_model_init (GdaDataModelIface *iface)
         iface->i_append_values = gnome_db_model_wrapper_append_row;
         iface->i_remove_row = gnome_db_model_wrapper_remove_row;
         iface->i_update_row = gnome_db_model_wrapper_update_row;
-        iface->i_append_column = gnome_db_model_wrapper_append_column;
-        iface->i_update_column = gnome_db_model_wrapper_update_column;
         iface->i_remove_column = gnome_db_model_wrapper_remove_column;
         iface->i_set_notify = gnome_db_model_wrapper_set_notify;
         iface->i_get_notify = gnome_db_model_wrapper_get_notify;
@@ -281,7 +271,7 @@ gnome_db_model_wrapper_new (GnomeDbDict *dict, GdaDataModel *model)
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 	g_return_val_if_fail (model && GDA_IS_DATA_MODEL (model), NULL);
 
-	obj = g_object_new (GNOME_DB_MODEL_WRAPPER_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_MODEL_WRAPPER, "dict", ASSERT_DICT (dict), NULL);
 	wrapper = GNOME_DB_MODEL_WRAPPER (obj);
 
 	wrapper->priv->model = model;
@@ -490,7 +480,7 @@ gnome_db_model_wrapper_model_copy (GnomeDbDataModel *iface, GHashTable *replacem
 	orig = GNOME_DB_MODEL_WRAPPER (iface);
 	g_return_val_if_fail (orig->priv, NULL);
 
-	obj = g_object_new (GNOME_DB_MODEL_WRAPPER_TYPE, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_MODEL_WRAPPER, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
 	wrapper = GNOME_DB_MODEL_WRAPPER (obj);
 
 	wrapper->priv->model = orig->priv->model;
@@ -670,43 +660,6 @@ gnome_db_model_wrapper_describe_column (GdaDataModel *model, gint col)
 		return NULL;
 }
 
-static void
-gnome_db_model_wrapper_set_column_title (GdaDataModel *model, gint col, const gchar *title)
-{
-	GdaDataModel *gdamodel;
-	g_return_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model));
-
-	gdamodel = GNOME_DB_MODEL_WRAPPER (model)->priv->model;
-	if (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_set_column_title)
-		(GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_set_column_title) (gdamodel, col, title);
-}
-
-static const gchar *
-gnome_db_model_wrapper_get_column_title (GdaDataModel *model, gint col)
-{
-	GdaDataModel *gdamodel;
-	g_return_val_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model), NULL);
-
-	gdamodel = GNOME_DB_MODEL_WRAPPER (model)->priv->model;
-	if (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_get_column_title)
-		return (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_get_column_title) (gdamodel, col);
-	else
-		return NULL;
-}
-
-static gint
-gnome_db_model_wrapper_get_column_pos (GdaDataModel *model, const gchar *title)
-{
-	GdaDataModel *gdamodel;
-	g_return_val_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model), -1);
-
-	gdamodel = GNOME_DB_MODEL_WRAPPER (model)->priv->model;
-	if (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_get_column_pos)
-		return (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_get_column_pos) (gdamodel, title);
-	else
-		return -1;
-}
-
 static const GdaRow *
 gnome_db_model_wrapper_get_row (GdaDataModel *model, gint row)
 {
@@ -835,29 +788,15 @@ gnome_db_model_wrapper_update_row (GdaDataModel *model, const GdaRow *row)
 		return FALSE;
 }
 
-static gboolean
-gnome_db_model_wrapper_append_column (GdaDataModel *model, const GdaColumn *attrs)
+static GdaColumn *
+gnome_db_model_wrapper_append_column (GdaDataModel *model)
 {
 	GdaDataModel *gdamodel;
 	g_return_val_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model), FALSE);
 
 	gdamodel = GNOME_DB_MODEL_WRAPPER (model)->priv->model;
 	if (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_append_column)
-		return (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_append_column) (gdamodel, attrs);
-	else
-		return FALSE;
-}
-
-static gboolean
-gnome_db_model_wrapper_update_column (GdaDataModel *model, gint col,
-				      const GdaColumn *attrs)
-{
-	GdaDataModel *gdamodel;
-	g_return_val_if_fail (IS_GNOME_DB_MODEL_WRAPPER (model), FALSE);
-
-	gdamodel = GNOME_DB_MODEL_WRAPPER (model)->priv->model;
-	if (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_update_column)
-		return (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_update_column) (gdamodel, col, attrs);
+		return (GDA_DATA_MODEL_GET_IFACE (gdamodel)->i_append_column) (gdamodel);
 	else
 		return FALSE;
 }
