@@ -60,7 +60,6 @@ static GnomeDbServerDataType *gnome_db_qf_all_get_data_type   (GnomeDbField *ifa
 
 /* Renderer interface */
 static void            gnome_db_qf_all_renderer_init      (GnomeDbRendererIface *iface);
-static GdaXqlItem     *gnome_db_qf_all_render_as_xql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error);
 static gchar          *gnome_db_qf_all_render_as_sql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error);
 static gchar          *gnome_db_qf_all_render_as_str   (GnomeDbRenderer *iface, GnomeDbDataSet *context);
 
@@ -193,7 +192,6 @@ gnome_db_qf_all_field_init (GnomeDbFieldIface *iface)
 static void
 gnome_db_qf_all_renderer_init (GnomeDbRendererIface *iface)
 {
-	iface->render_as_xql = gnome_db_qf_all_render_as_xql;
 	iface->render_as_sql = gnome_db_qf_all_render_as_sql;
 	iface->render_as_str = gnome_db_qf_all_render_as_str;
 	iface->is_valid = NULL;
@@ -706,17 +704,6 @@ gnome_db_qf_all_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError
 /*
  * GnomeDbRenderer interface implementation
  */
-static GdaXqlItem *
-gnome_db_qf_all_render_as_xql (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error)
-{
-	GdaXqlItem *node = NULL;
-
-	g_return_val_if_fail (iface && IS_GNOME_DB_QF_ALL (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_QF_ALL (iface)->priv, NULL);
-	
-	TO_IMPLEMENT;
-	return node;
-}
 
 static gchar *
 gnome_db_qf_all_render_as_sql (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error)
