@@ -28,7 +28,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_REF_BASE_TYPE          (gnome_db_ref_base_get_type())
+#define GNOME_DB_TYPE_REF_BASE          (gnome_db_ref_base_get_type())
 #define GNOME_DB_REF_BASE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_ref_base_get_type(), GnomeDbRefBase)
 #define GNOME_DB_REF_BASE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_ref_base_get_type (), GnomeDbRefBaseClass)
 #define IS_GNOME_DB_REF_BASE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_ref_base_get_type ())
