@@ -62,7 +62,6 @@ static GnomeDbServerDataType *gnome_db_table_field_get_data_type   (GnomeDbField
 
 /* Renderer interface */
 static void            gnome_db_table_field_renderer_init      (GnomeDbRendererIface *iface);
-static GdaXqlItem     *gnome_db_table_field_render_as_xql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error);
 static gchar          *gnome_db_table_field_render_as_sql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error);
 static gchar          *gnome_db_table_field_render_as_str   (GnomeDbRenderer *iface, GnomeDbDataSet *context);
 
@@ -173,7 +172,6 @@ gnome_db_table_field_field_init (GnomeDbFieldIface *iface)
 static void
 gnome_db_table_field_renderer_init (GnomeDbRendererIface *iface)
 {
-	iface->render_as_xql = gnome_db_table_field_render_as_xql;
 	iface->render_as_sql = gnome_db_table_field_render_as_sql;
 	iface->render_as_str = gnome_db_table_field_render_as_str;
 	iface->is_valid = NULL;
@@ -999,17 +997,6 @@ gnome_db_table_field_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, G
 /*
  * GnomeDbRenderer interface implementation
  */
-static GdaXqlItem *
-gnome_db_table_field_render_as_xql (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error)
-{
-	GdaXqlItem *node = NULL;
-
-	g_return_val_if_fail (iface && IS_GNOME_DB_TABLE_FIELD (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_TABLE_FIELD (iface)->priv, NULL);
-	
-	TO_IMPLEMENT;
-	return node;
-}
 
 static gchar *
 gnome_db_table_field_render_as_sql (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error)
