@@ -62,7 +62,6 @@ static void        gnome_db_target_replace_refs        (GnomeDbReferer *iface, G
 
 /* Renderer interface */
 static void        gnome_db_target_renderer_init   (GnomeDbRendererIface *iface);
-static GdaXqlItem *gnome_db_target_render_as_xql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error);
 static gchar      *gnome_db_target_render_as_sql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error);
 static gchar      *gnome_db_target_render_as_str   (GnomeDbRenderer *iface, GnomeDbDataSet *context);
 
@@ -173,7 +172,6 @@ gnome_db_target_referer_init (GnomeDbRefererIface *iface)
 static void
 gnome_db_target_renderer_init (GnomeDbRendererIface *iface)
 {
-	iface->render_as_xql = gnome_db_target_render_as_xql;
 	iface->render_as_sql = gnome_db_target_render_as_sql;
 	iface->render_as_str = gnome_db_target_render_as_str;
 	iface->is_valid = NULL;
@@ -786,15 +784,6 @@ gnome_db_target_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError
 /* 
  * GnomeDbRenderer interface implementation
  */
-static GdaXqlItem *
-gnome_db_target_render_as_xql (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error)
-{
-	g_return_val_if_fail (iface && IS_GNOME_DB_TARGET (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_TARGET (iface)->priv, NULL);
-
-	TO_IMPLEMENT;
-	return NULL;
-}
 
 static gchar *
 gnome_db_target_render_as_sql (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error)
