@@ -83,7 +83,7 @@ gnome_db_canvas_join_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_join_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_ITEM_TYPE, "GnomeDbCanvasJoin", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS_ITEM, "GnomeDbCanvasJoin", &info, 0);
 	}
 
 	return type;
