@@ -124,8 +124,8 @@ gnome_db_graph_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbGraph", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbGraph", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
 	}
 	return type;
 }
@@ -237,7 +237,7 @@ gnome_db_graph_new (GnomeDbDict *dict, GnomeDbGraphType type)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_GRAPH_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_GRAPH, "dict", ASSERT_DICT (dict), NULL);
 	graph = GNOME_DB_GRAPH (obj);
 
 	g_object_get (G_OBJECT (ASSERT_DICT (dict)), "graph_serial", &id, NULL);
