@@ -98,8 +98,8 @@ gnome_db_handler_passmd5_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbHandlerPassmd5", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_HANDLER_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbHandlerPassmd5", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_HANDLER, &data_entry_info);
 	}
 	return type;
 }
